@@ -86,7 +86,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54d00
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x54d00
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -124,5 +124,12 @@
 #define KCODECS_DEPRECATED_VERSION_5(minor, text)      KCODECS_DEPRECATED_VERSION_5_##minor(text)
 #define KCODECS_DEPRECATED_VERSION(major, minor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCODECS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCODECS_DEPRECATED_VERSION(major, minor, text)
+#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCODECS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCODECS_EXPORT_H */
